/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.extension.autoloader;

import java.io.File;
import java.io.FilenameFilter;

/**
 * <p>
 * Filter for autoloading.
 * </p>
 * <p>
 * Return true if the file is an archive : JAR or ZIP, and no Firefox download
 * is in progress.
 * </p>
 * 
 * @author Adrien Louis - EBM WebSourcing
 */
final class ArchiveFileFilter implements FilenameFilter {

    private static ArchiveFileFilter instance = new ArchiveFileFilter();

    public static ArchiveFileFilter getInstance() {
        return ArchiveFileFilter.instance;
    }

    /**
     * @see java.io.FilenameFilter#accept(java.io.File, java.lang.String)
     */
    public boolean accept(File dir, String name) {

        // JAR and ZIP files are accepted.
        // When downloading a file with Firefox, a temporary file with the same
        // name suffixed by '.part' is created and must be rejected.
        final String lcName = name.toLowerCase();

        if ((lcName.endsWith("jar") || lcName.endsWith("zip"))
                && !new File(dir, name + ".part").exists()) {
            return true;
        }
        return false;
    }
}